@@ -22,6 +22,7 @@ from ai.h2o.sparkling.ml.algos.regression import H2OGBMRegressor
 from ai.h2o.sparkling.ml.algos.regression import H2OXGBoostRegressor
 from ai.h2o.sparkling.ml.algos.regression import H2ODeepLearningRegressor
 from ai.h2o.sparkling.ml.algos.regression import H2ODRFRegressor
+from ai.h2o.sparkling.ml.algos.regression import H2ORuleFitRegressor
 
 __all__ = [
     "H2OAutoMLRegressor",
@@ -30,4 +31,5 @@ __all__ = [
     "H2OGBMRegressor",
     "H2OXGBoostRegressor",
     "H2ODeepLearningRegressor",
-    "H2ODRFRegressor"]
+    "H2ODRFRegressor",
+    "H2ORuleFitRegressor"]
